using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Todo.Core.Interfaces.Persistence;

namespace Todo.Api.Controllers;

[ApiController]
[Route("/api/todos")]
public class TodosController : ControllerBase
{
    private readonly ITodoRepository _todoRepository;

    public TodosController(ITodoRepository todoRepository)
    {
        _todoRepository = todoRepository;
    }

    public record CreateTodoRequest
    {
        [Required] public string Title { get; init; }
    }

    [HttpPost]
    public async Task<ActionResult<Core.Entities.Todo>> CreateTodo([FromBody] CreateTodoRequest request)
    {
        var todo = await _todoRepository.CreateTodoAsync(request.Title);

        return Ok(todo);
    }

    [HttpGet]
    public async Task<ActionResult<IEnumerable<Core.Entities.Todo>>> GetTodos()
    {
        var todos = await _todoRepository.GetTodosAsync();

        return Ok(todos);
    }
}